//=======================================================================
// preferences.h
//-----------------------------------------------------------------------
// This file is part of the package paco
// Copyright (C) 2004-2009 David Rosal
// For more information visit http://paco.sourceforge.net
//=======================================================================

#ifndef GPACO_PREFERENCES_H
#define GPACO_PREFERENCES_H

#include "maintreeview.h"
#include <gtkmm/dialog.h>
#include <gtkmm/checkbutton.h>

namespace Gpaco {

class MainWindow;

class Preferences : public Gtk::Dialog
{
	public:

	Preferences(MainWindow&);

	private:

	Gtk::CheckButton*	mButtons[MainTreeView::N_COLS];
	Gtk::CheckButton	mButtonHour;
	MainWindow&			mMainWindow;

	void response(int id);
	void ok();
	void onButtonClicked();
};

} // namespace Gpaco


#endif  // GPACO_PREFERENCES_H

